@@ -44,8 +44,14 @@ pub fn find_champ<'a>(
         let mut lowest_distance: i32 = i32::MAX;
         let mut closest_champ: &ChampionDatum = &champ_data["Annie"];
         for (_key, value) in champ_data {
-            let distance = levenshtein(name, value.name.as_str()) as i32;
-            if distance < lowest_distance {
+            let query_compare = name.to_ascii_lowercase();
+            let champ_compare = value.name.to_ascii_lowercase();
+            // Prefer matches where search query is an exact starting substring
+            if champ_compare.starts_with(&query_compare) {
+                return value;
+            }
+            let distance = levenshtein(query_compare.as_str(), champ_compare.as_str()) as i32;
+            if distance <= lowest_distance {
                 lowest_distance = distance;
                 closest_champ = value;
             }
@@ -151,6 +157,7 @@ pub fn clear_cache(cache_dir: &str, filename: &String) {
     }
 }
 
+#[cfg(any(target_os = "windows", target_os = "macos"))]
 pub fn generate_perk_array(
     runes: &Vec<(String, Vec<&RuneExtended>)>,
     shards: &Vec<i64>,
